/***********************************************************************************************/
/* 	SIERRA LEONE ETHNIC DIVERSITY PAPER													       */
/*																							   */
/* 		Alex Rothenberg																		   */
/* 		UC - Berkeley, Department of Economics												   */
/* 		Summer 2012																			   */
/*																							   */
/*	First Stage Regressions																       */
/***********************************************************************************************/
#delimit;
set more off;
set matsize 800;
pause on;
capture log close;

/* CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE */;
global REPDIR = "/Users/alexroth/Documents/Papers/SL_Diversity/SL_EJ/";

global DV_do 	 "$REPDIR/STATA/do/";
global DV_data 	 "$REPDIR/STATA/dta/";
global outputRNR "$REPDIR/Output/";
global outputPNG "$REPDIR/Output/PNG/";
global outputEPS "$REPDIR/Output/EPS/";

/* ======================================================== */
/*	I.  First Stage Results, Chiefdom-Level				    */  
/* ======================================================== */
	use "$DV_data/ethnic_ch_0507.dta", clear;			

	drop if year == 2005;
	
	sort chief_2004census;
	
	merge 1:1 chief_2004census using "$DV_data/newvars.dta";
		drop if _merge == 2;
		drop _merge;
	
	label var elf_ch_63 "Ethnic Fractionalization (ELF), 1963";

	local controls = "i_c_index female young middle_aged muslim ed econ_status leader";
	local geoControls = "rugged3 riverdist coastdist Elev30as slope34 slopecl5 slopecl6 slope78";
	local soilvars "drainage123 drainage67 texture1 texture2 t_oc t_ece t_esp t_ph_h2o";
	local instvars "numfamilies missionCount amalgamation";

	eststo clear;
	
	eststo : regress elf_ch elf_ch_63 [pw = inv_prob_ch], robust;
		estadd local npsControls = ".";
		estadd local geography   = ".";
		estadd local soilquality = ".";
		estadd local instquality = ".";

	eststo : regress elf_ch elf_ch_63 `controls' `geoControls' `soilvars' `instvars' 
		[pw = inv_prob_ch], robust;
		estadd local npsControls = "Yes";
		estadd local geography   = "Yes";
		estadd local soilquality = "Yes";
		estadd local instquality = "Yes";

	estout using "$outputRNR/first_stage_elf.tex", replace 
		keep(elf_ch_63)
		label
		cells(b(fmt(3)) se(par star fmt(3)) .) dropped(".")
		stats(r2_a N F npsControls geography soilquality instquality, 
			labels("Adj. \$R^{2}\$" "\$N\$" "\$F\$ Stat"
			"Survey Covariates" "Geographic Covariates" "Soil Quality Covariates" "Institutional Covariates") 
			fmt(%9.3f %9.0f %9.2f %3s %3s %3s %3s)) 
		starlevels(* 0.1 ** 0.05 *** 0.01) varwidth(15) 
		prefoot("\midrule")
		mlabels(, none) collabels(, none)
		substitute(_ \_) style(tex);


/* ======================================================== */
/*	II. Graphical Representation of First Stage				*/  
/* ======================================================== */
	/* -------------------------------------------------------- */
	/*  II.A  Bivariate Plot									*/
	/* -------------------------------------------------------- */
	twoway (scatter elf_ch elf_ch_63, mcolor(gs12) mlcolor(gs0)) 
		(lfit elf_ch elf_ch_63, lcolor(black)),
		graphregion(color(white))
		ytitle("ELF (2004)")
		xtitle("ELF (1963)")
		legend(off);
		
	graph export "$outputRNR/1st_Stage_Bivariate_ch.png", as(png) replace;
	graph export "$outputPNG/Rothenberg_Fig3A_1st_Stage_Bivariate_ch.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_Fig3A_1st_Stage_Bivariate_ch.eps", as(eps) replace;
	
	/* -------------------------------------------------------- */
	/*  II.B  Frisch-Waugh Plot, Only Level Shares				*/
	/* -------------------------------------------------------- */
	regress elf_ch `controls' `geoControls' `soilvars' `instvars'  [pw = inv_prob_ch], robust;	
	predict y_resid if e(sample), residuals;
		label var y_resid "Residuals, ELF (2004)";
	
	regress elf_ch_63 `controls' `geoControls' `soilvars' `instvars' [pw = inv_prob_ch], robust;	
	predict x_resid if e(sample), residuals;
		label var x_resid "Residuals, ELF (1963)";

	twoway (scatter y_resid x_resid, mcolor(gs12) mlcolor(gs0)) 
		(lfit y_resid x_resid, lcolor(black)),
		graphregion(color(white))
		ytitle("Residuals, ELF (2004)")
		legend(off);
		
	graph export "$outputRNR/1st_Stage_FrischWaugh_ch.png", as(png) replace;
	graph export "$outputPNG/Rothenberg_Fig3B_1st_Stage_FrischWaugh_ch.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_Fig3B_1st_Stage_FrischWaugh_ch.eps", as(eps) replace;
