/***********************************************************************************************/
/* 	SIERRA LEONE ETHNIC DIVERSITY PAPER													       */
/*																							   */
/*		5 March 2010																		   */
/*		- Alex Rothenberg 																	   */
/*																							   */
/*	Logit Regressions																		   */
/***********************************************************************************************/
#delimit;
clear all;
set more off;
set matsize 800;
set memory 1g;

pause on;
capture log close;

/* CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE */;
global REPDIR = "/Users/alexroth/Documents/Papers/SL_Diversity/SL_EJ/";

global DV_do 	 "$REPDIR/STATA/do/";
global DV_data 	 "$REPDIR/STATA/dta/";
global outputRNR "$REPDIR/Output/";
global outputPNG "$REPDIR/Output/PNG/";
global outputEPS "$REPDIR/Output/EPS/";

/* ======================================================== */
/*  I.  Summary Statistics									*/
/* ======================================================== */
	/* -------------------------------------------------------- */
	/* 	I.A  Creating Variables						  			*/
	/* -------------------------------------------------------- */
	use "$DV_data/logit_db_analysis.dta", clear;
	
	keep if depvar == 1;

	gen dist_home 	= floor(chief_home / 100);
	gen dist_now 	= floor(chief_now / 100);
	
	gen moved_chief = (chief_home != chief_now);
		label var moved_chief "Moved between chiefdoms/locations (1990 to 2007)";

	gen moved_dist  = (dist_home  != dist_now);
		label var moved_dist "Moved between districts (1990 to 2007)";
	
	label var dist "Distance moved (in kilometers)";

	gen dist_if_moved = dist;
		replace dist_if_moved = . if (chief_home == chief_now);
		label var dist_if_moved "Distance moved (in kilometers), if moved";

	log using "$outputRNR/TabA1-logit_summary_stats.txt", replace;
	/* -------------------------------------------------------- */
	/* 	I.B  Table A1:  Summary Statistics, Logit		  		*/
	/* -------------------------------------------------------- */
	fsum moved_chief moved_dist dist dist_if_moved ed ruling refugee_hh, 
		f(10.3) s(n mean sd) label;

	capture log close;


/* ======================================================== */
/*	II.  Logit Models									    */  
/* ======================================================== */
	use "$DV_data/logit_db_analysis.dta", clear;

	label var dist "Distance between chiefdoms";
	label var own_eth "Co-ethnic population share";
	label var elf_ch_63 "Ethnolinguistic Fractionalization (ELF)";
	
	label var eduXdist "Any education $\times$ Distance";
	label var eduXown "Any education $\times$ Co-ethnic";
	label var eduXelf "Any education $\times$ ELF";

	label var ruleXdist "Ruling family member $\times$ Distance";
	label var ruleXown "Ruling family member $\times$ Co-ethnic";
	label var ruleXelf "Ruling family member $\times$ ELF";

	label var conXdist "Experienced war violence $\times$ Distance";
	label var conXown "Experienced war violence $\times$ Co-ethnic";
	label var conXelf "Experienced war violence $\times$ ELF";

	label var trustXdist "Trust outsiders $\times$ Distance";
	label var trustXown "Trust outsiders $\times$ Co-ethnic";
	label var trustXelf "Trust outsiders $\times$ ELF";

	label var leader1990Xdist "1990 group leader $\times$ Distance";
	label var leader1990Xown "1990 group leader $\times$ Co-ethnic";
	label var leader1990Xelf "1990 group leader $\times$ ELF";

	label var pop_1985 "Chiefdom population (1985)";
	label var pop_dens_85 "Chiefdom population density (1985)";
	label var roads_dist "Distance to a road";
	label var remoteness "Distance to a city";
	label var n_atbt "Attacks and battles in the civil war";
	label var allmining "Any mining in chiefdom";

	/* -------------------------------------------------------- */
	/* 	II.A  Original Table									*/
	/* -------------------------------------------------------- */
	eststo clear;
	
	eststo: clogit depvar dist own_eth pop_1985 pop_dens_85 roads_dist remoteness n_atbt allmining 
		[pweight = logit_weight_ch], group(idcase);
		
   	eststo: clogit depvar dist own_eth eduXdist eduXown conXdist conXown ruleXdist ruleXown trustXdist trustXown 
		leader1990Xdist leader1990Xown
		pop_1985 pop_dens_85 roads_dist remoteness n_atbt allmining
   		[pweight = logit_weight_ch], group(idcase);
   
    eststo: clogit depvar dist elf_ch_63 pop_1985 pop_dens_85 roads_dist remoteness n_atbt allmining
    	[pweight = logit_weight_ch], group(idcase);
   
    eststo: clogit depvar dist elf_ch_63 eduXdist eduXelf conXdist conXelf ruleXdist ruleXelf trustXdist trustXelf
		leader1990Xdist leader1990Xelf
		pop_1985 pop_dens_85 roads_dist remoteness n_atbt allmining 
   		[pweight = logit_weight_ch], group(idcase);	
   	
	estout using "$outputRNR/logit_models.tex", replace 
		keep(dist own_eth elf_ch_63 edu* rule* con* trust* leader*)
		order(dist own_eth elf_ch_63 eduXdist eduXown eduXelf conXdist conXown conXelf 
			ruleXdist ruleXown ruleXelf trustXdist trustXown trustXelf leader1990Xdist leader1990Xown leader1990Xelf)
		label
		cells(b(fmt(3)) se(par star fmt(3))) dropped(".")
		stats(ll r2_p, 
			labels("Log Pseudolikelihood" "Pseudo \$R^{2}\$") 
			fmt(%9.3f %9.3f)) 
		starlevels(* 0.1 ** 0.05 *** 0.01) varwidth(15) 
		prefoot("\midrule")
		mlabels(, none) collabels(, none)
		substitute(_ \_) style(tex);
		