/***********************************************************************************************/
/* 	SIERRA LEONE ETHNIC DIVERSITY PAPER													       */
/*																							   */
/*		5 March 2010																		   */
/*		- Alex Rothenberg 																	   */
/*																							   */
/*	Logit Regressions																		   */
/***********************************************************************************************/
#delimit;
clear all;
set more off;
set matsize 800;
set memory 1g;

pause on;
capture log close;

/* CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE */;
global REPDIR = "/Users/alexroth/Documents/Papers/SL_Diversity/SL_EJ/";

global DV_do 	 "$REPDIR/STATA/do/";
global DV_data 	 "$REPDIR/STATA/dta/";
global outputRNR "$REPDIR/Output/";
global outputPNG "$REPDIR/Output/PNG/";
global outputEPS "$REPDIR/Output/EPS/";
global DV_GIS 	 "$REPDIR/GIS/";

/* ======================================================== */
/*  I.  Getting Boundaries for Choropleth Maps				*/
/* ======================================================== */
	use "$DV_data/ethnic_analysis_chiefdom.dta", clear;
	centile elf_ch, centile(20);
		local b1 = round(r(c_1),0.001);
		
	centile elf_ch, centile(40);		
		local b2 = round(r(c_1),0.001);

	centile elf_ch, centile(60);
		local b3 = round(r(c_1),0.001);

	centile elf_ch, centile(80);
		local b4 = round(r(c_1),0.001);


/* ======================================================== */
/*  II.  Creating Shapefile Database						*/
/* ======================================================== */
	shp2dta using "$DV_GIS/Chiefdom_boundaries_2004.shp", replace database("$DV_GIS/chiefshape") 
		coordinates("$DV_GIS/chiefcoord") genid(id);

	use "$DV_GIS/chiefshape.dta", clear;
	sort ID_;
	merge ID_ using "$DV_data/ethnic_analysis_chiefdom.dta";


/* ======================================================== */
/*  III.  Producing Maps									*/
/* ======================================================== */
	replace elf_ch = . if n == .;
	replace elf_ch_lang = . if n == .;
	
	spmap elf_ch using "$DV_GIS/chiefcoord.dta", id(id) clmethod(custom) clbreaks(0 `b1' `b2' `b3' `b4' 1) 
		ndfcolor(gs16) ndsize(thick);
	graph export "$outputRNR/elf_ch_map.png", as(png) replace;
	graph export "$outputPNG/Rothenberg_Fig2A_elf_ch_map.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_Fig2A_elf_ch_map.eps", as(eps) replace;
	
	spmap elf_ch_63 using "$DV_GIS/chiefcoord.dta", id(id) clmethod(custom) clbreaks(0 `b1' `b2' `b3' `b4' 1) 
		ndfcolor(gs16) ndsize(thick);		
	graph export "$outputRNR/elf_ch_63_map.png", as(png) replace;
	graph export "$outputPNG/Rothenberg_Fig2B_elf_ch_63_map.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_Fig2B_elf_ch_63_map.eps", as(eps) replace;
	
	spmap elf_relig_ch using "$DV_GIS/chiefcoord.dta", id(id) clmethod(custom) clbreaks(0 `b1' `b2' `b3' `b4' 1)
		ndfcolor(gs16) ndsize(thick);
	graph export "$outputRNR/elf_relig_ch_map.png", as(png) replace;
	graph export "$outputPNG/Rothenberg_FigA1_elf_relig_ch_map.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_FigA1_elf_relig_ch_map.eps", as(eps) replace;
	
	spmap hcon_all_2004 using "$DV_GIS/chiefcoord.dta", id(id) clmethod(custom) clbreaks(0 `b1' `b2' `b3' `b4' 1) 
		ndfcolor(gs16) ndsize(thick);
	graph export "$outputRNR/hcon_2004_map.png", as(png) replace; 
	graph export "$outputPNG/Rothenberg_FigA2_hcon_2004_map.png", as(png) replace;
	graph export "$outputEPS/Rothenberg_FigA2_hcon_2004_map.eps", as(eps) replace;
