/***********************************************************************************************/
/* 	SIERRA LEONE ETHNIC DIVERSITY PAPER													       */
/*																							   */
/*		5 March 2010																		   */
/*		- Alex Rothenberg 																	   */
/*																							   */
/*	Mean Effects Regressions															       */
/***********************************************************************************************/
#delimit;
clear all;
set more off;
set matsize 800;
set memory 1g;

pause on;
capture log close;

/* CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE */;
global REPDIR = "/Users/alexroth/Documents/Papers/SL_Diversity/SL_EJ/";

global DV_do 	 "$REPDIR/STATA/do/";
global DV_data 	 "$REPDIR/STATA/dta/";
global outputRNR "$REPDIR/Output/";
global outputPNG "$REPDIR/Output/PNG/";
global outputEPS "$REPDIR/Output/EPS/";
global DV_GIS 	 "$REPDIR/GIS/";
		
/* ======================================================== */
/*	I.  Declaring Local Variables						    */  
/* ======================================================== */
	local supplies_vars = "e_desks e_chairs e_pupilbench e_blackboard e_textbooks";
	local facil_vars  = "f_toilet f_elec f_piped_water f_bldg_good";
	local teach_vars  = "e_pupilteacher e_badteacher f_teacher_present_sur";
	
	local schoolVarlist : list supplies_vars | facil_vars;
	local schoolVarlist : list schoolVarlist | teach_vars;

	local varlist = "group_any group_credit group_school road_brushing comm_labor 
		comm_meetings trust_own trust_outside trust_lc trust_cg dispute_theft dispute_land dispute_attack";

	local dset = "0507";	

	/* Ethnolinguistic Diversity */;
	/* OLS + IV */;
	local indvar = "elf_ch";
	local iv_ind = "elf_ch_63";

	*local indvar = "elf_ch_lang";
	*local iv_ind = "elf_ch_63_lang"; 

	*local indvar = "hcon_all_2004";
	*local iv_ind = "hcon_all_1963";

	*local indvar = "elf_relig_ch";
	*local iv_ind = "elf_ch_63";

	local controls 		= "i_c_index female young middle_aged muslim ed econ_status leader";
	local geoControls 	= "rugged3 riverdist coastdist Elev30as slope34 slopecl5 slopecl6 slope78";
	local soilvars 		= "drainage123 drainage67 texture1 texture2 t_oc t_ece t_ph_h2o";
	local instvars 		= "numfamilies missionCount amalgamation";

	local newControls : list geoControls | soilvars;
	local newControls : list newControls | instvars;

	local controls_1 = "";	
	local controls_2 = "`controls' `geoControls' `soilvars' `instvars'"; 
	local controls_3 = "`controls' `geoControls' `soilvars' `instvars' i_conXelf"; 	

	local MEcontrols_1 = "";	
	local MEcontrols_2 = "`controls'"; 
	local MEcontrols_3 = "`controls' `geoControls' `soilvars' `instvars'"; 	

	local MESchoolcontrols_1 = "";	
	local MESchoolcontrols_2 = "allmining"; 
	local MESchoolcontrols_3 = "allmining `geoControls' `soilvars' `instvars'"; 	

	local meanEffectTitle  = "allControls";
	*local meanEffectTitle  = "allControls_langFamily";
	*local meanEffectTitle  = "allControls_histCon";
	*local meanEffectTitle  = "allControls_religion";
	local figureString     = "$outputRNR/results_nps_`indvar'_`dset'_`meanEffectTitle'.png";
	local figureStringPNG  = "$outputPNG/Rothenberg_Fig5_nps_`indvar'_`dset'_`meanEffectTitle'.png";
	local figureStringEPS  = "$outputPNG/Rothenberg_Fig5_nps_`indvar'_`dset'_`meanEffectTitle'.eps";
		
	/* Religious Diversity */;
	/* OLS ONLY */;
	/*
	local indvar = "elf_relig_ch";
	local shares = "e_christian e_muslim"; 
    local squareshares = " "; 

	local iv_ind = "elf_ch_63";
	local iv_shares = "e_Mende_63_ch e_Temne_63_ch"; 
    local iv_squareshares = "e_Mende_63_ch_2 e_Temne_63_ch_2";

	local controls_1 = "";	
	local controls_2 = "i_c_index"; 
	local controls_3 = "i_c_index female young middle_aged ed econ_status leader"; 
	local controls_4 = "i_c_index female young middle_aged ed econ_status leader i_conXelf";	 
	*/
	
	/* Language-Family ELF */;
	/* OLS + IV */;
	/*
	local indvar = "elf_ch_lang";
	local shares = "e_Mande_lang_ch e_Atl_Congo_lang_ch";
	local squareshares = " ";
	
	local iv_ind = "elf_ch_63_lang"; 
	local iv_shares = "e_Mande_lang_63_ch e_Atl_Congo_lang_63_ch"; 
    local iv_squareshares = " ";	

	local controls_1 = "";	
	local controls_2 = "i_c_index"; 
	local controls_3 = "i_c_index female young middle_aged muslim ed econ_status leader"; 
	local controls_4 = "i_c_index female young middle_aged muslim ed econ_status leader i_conXelf";
	*/

	/* Historical Conflict Index */;
	/*
	local indvar = "hcon_all_2004";
	local shares = "e_Mende_ch e_Temne_ch"; 
    local squareshares = "e_Mende_ch_2 e_Temne_ch_2"; 

	local iv_ind = "hcon_all_1963";
	local iv_shares = "e_Mende_63_ch e_Temne_63_ch"; 
    local iv_squareshares = "e_Mende_63_ch_2 e_Temne_63_ch_2";

	local controls_1 = "";	
	local controls_2 = "i_c_index"; 
	local controls_3 = "i_c_index female young middle_aged ed econ_status leader"; 
	local controls_4 = "i_c_index female young middle_aged ed econ_status leader i_conXelf";	 
	*/
	

/* ======================================================== */
/*	II.  Individual Regressions (for Figures)			    */
/* ======================================================== */
	* List of Dependent Variables 2005-2007;
	local dvlist = "group_any group_credit group_school road_brushing comm_labor comm_meetings 
		trust_own trust_outside trust_lc trust_cg dispute_theft dispute_attack dispute_land";
	
	use "$DV_data/ethnic_ch_`dset'.dta", clear;

	sort chief_2004census;
	
	merge m:1 chief_2004census using "$DV_data/newvars.dta";
		drop if _merge == 2;
		drop _merge;
			
	sum `indvar', detail;
		local cutoff = r(p50);
		local sigmaX = r(sd);
		
	gen control = (`indvar' < `cutoff');	
	
	foreach dv of local dvlist {;
	
		gen `dv'_z = .;
		qui sum `dv' if control == 1;
		 	local mean = r(mean);
		 	local sd = r(sd);
		
		replace `dv'_z = ((`dv'-`mean') / `sd');	
				
		ivreg2 `dv'_z (`indvar' = `iv_ind') `controls_3' [pw = inv_prob_ch], robust;
		
		nlcom _b[`indvar']*`sigmaX';
			local `dv'_point = el(r(b),1,1);
			local `dv'_se = sqrt(el(r(V),1,1));
			local `dv'_ub 	 =  ``dv'_point' + (1.959964*``dv'_se');
			local `dv'_lb 	 =  ``dv'_point' - (1.959964*``dv'_se');
		};	

/* ======================================================== */
/*	III.  Individual Regressions (in Levels)			    */
/* ======================================================== */
	use "$DV_data/ethnic_ch_`dset'.dta", clear;

	sort chief_2004census;
	
	merge m:1 chief_2004census using "$DV_data/newvars.dta";
		drop if _merge == 2;
		drop _merge;
	
	foreach dv of local dvlist {;
	
		eststo clear;

		eststo:  reg `dv' `indvar' `controls_1' [pw = inv_prob_ch], robust; 
			
		eststo:  reg `dv' `indvar' `controls_3' [pw = inv_prob_ch], robust; 

		eststo:  ivreg2 `dv' (`indvar' = `iv_ind') `controls_1' [pw = inv_prob_ch], robust; 
		   	      
		eststo:  ivreg2 `dv' (`indvar' = `iv_ind') `controls_3' [pw = inv_prob_ch], robust; 

		estout using "$outputRNR/indivRegs/`dv'_`indvar'_`dset'_ch.tex", replace
			drop(_cons)
			cells(b(fmt(3)) se(par star fmt(3)) .) dropped(".")
			stats(r2_a N, 
		   		labels("Adjusted \$R^{2}\$" "\$N\$") 
		   		fmt(%9.3f %9.0f)) 
			starlevels(* 0.1 ** 0.05 *** 0.01) varwidth(15) 
			mlabels(, none) collabels(, none)
			prefoot("\midrule")
			substitute(_ \_) style(tex);			
	 	};		
	
	
/* ======================================================== */
/*	IV.  Preparing for Mean Effects Analysis			    */
/* ======================================================== */
	use "$DV_data/ethnic_ch_`dset'.dta", clear;

	sort chief_2004census;
	
	merge m:1 chief_2004census using "$DV_data/newvars.dta";
		drop if _merge == 2;
		drop _merge;

	merge m:1 chief_2004census using "$DV_data/schools_small.dta";
		drop if _merge == 2;
		drop _merge;
		
	foreach var of local schoolVarlist {;
		replace `var' = 0 if `var' == . & year == 2005;
		};
					
	if "`dset'" == "0507" {; 
		
		drop elf_ea_lang pce_04 e_Mande_lang_ea e_Atl_Congo_lang_ea e_Other_lang_ea e_Other_lang_ea_2
			e_Mande_lang_ea_2 e_Atl_Congo_lang_ea_2 eduChief_ea ageChief_ea wealthChief_ea;
		
		reshape i chief_2004census;
		reshape j year;
		
		reshape xij group_any group_credit group_school comm_meetings trust_own trust_outside trust_lc 
			trust_cg dispute_theft dispute_attack young middle_aged female ed leader econ_status 
			christian muslim minority_ch i_c_index i_conXelf minorXelf road_brushing comm_labor 
			dispute_land ruling migrant90 inv_prob_ch `schoolVarlist';
			
		reshape wide;
		drop inv_prob_ch2005;
		rename inv_prob_ch2007 inv_prob_ch;
	
		drop e_desks2007 e_chairs2007 e_pupilbench2007 e_blackboard2007 e_textbooks2007 
			f_toilet2007 f_elec2007 f_piped_water2007 f_bldg_good2007 e_pupilteacher2007 
			e_badteacher2007 f_teacher_present_sur2007;
		
		};

	/* -------------------------------------------------------- */
	/*	IV.A  Defining the Control Group						*/
	/* -------------------------------------------------------- */
	sum `indvar', detail;
		local cutoff = r(p50);
	gen control = (`indvar' < `cutoff');

	/* -------------------------------------------------------- */
	/*	IV.B  Creating Macros for Groupings of Dependent Vars	*/
	/* -------------------------------------------------------- */
	local groupings = "comm group disp trust";

	local group_vars05 = "group_any2005 group_credit2005 group_school2005";
	local group_vars07 = "group_any2007 group_credit2007 group_school2007";
		local group_vars : list group_vars05 | group_vars07;

	local comm_vars05  = "comm_meetings2005";
	local comm_vars07  = "road_brushing2007 comm_labor2007 comm_meetings2007";
		local comm_vars : list comm_vars05 | comm_vars07;
			
	local disp_vars05  = "dispute_theft2005 dispute_attack2005";	
	local disp_vars07  = "dispute_theft2005 dispute_attack2005 dispute_land2007";	
		local disp_vars : list disp_vars05 | disp_vars07;
						
	local trust_vars05 = "trust_own2005 trust_outside2005 trust_lc2005 trust_cg2005";
	local trust_vars07 = "trust_own2007 trust_outside2007 trust_lc2007 trust_cg2007";			
		local trust_vars : list trust_vars05 | trust_vars07;

	local school_vars1 = "e_desks2005 e_chairs2005 e_pupilbench2005 e_blackboard2005 e_textbooks2005"; 
	local school_vars2 = "f_toilet2005 f_elec2005 f_piped_water2005 f_bldg_good2005 e_pupilteacher2005"; 
	local school_vars3 = "e_badteacher2005 f_teacher_present_sur2005";
		
	local mean_vars	: list group_vars | comm_vars;
	local mean_vars	: list mean_vars  | disp_vars;
	local mean_vars	: list mean_vars  | school_vars1;
	local mean_vars	: list mean_vars  | school_vars2;
	local mean_vars	: list mean_vars  | school_vars3;
	
	local Omean_vars : list mean_vars | trust_vars;

	/* -------------------------------------------------------- */
	/*	IV.C  Creating the Z-Score Average Dependent Variable	*/
	/* -------------------------------------------------------- */
	foreach gp of local groupings {; 
		
		gen `gp'_medv = 0;
		
		foreach var of local `gp'_vars {;
			local size : list sizeof `gp'_vars;
				
			qui sum `var' if control == 1;
		 		local mean = r(mean);
		 		local sd = r(sd);
			
			replace `gp'_medv = `gp'_medv + ((`var'-`mean') / `sd');
			};
			
			replace `gp'_medv = `gp'_medv / `size';		
		};
		
	/* -------------------------------------------------------- */
	/*	IV.D  Creating Overall Mean Effect Z-Score				*/
	/* -------------------------------------------------------- */
	foreach var of local disp_vars {;
		replace `var' = (-1) * `var';		
		};	
	
	gen mean_medv = 0;
		local size : list sizeof mean_vars;
		
	foreach var of local mean_vars {;
				
		qui sum `var' if control == 1;
		 	local mean = r(mean);
		 	local sd = r(sd);
			
		replace mean_medv = mean_medv + ((`var'-`mean') / `sd');
		};
			
		replace mean_medv = mean_medv / `size';	

	gen Omean_medv = 0;
		local size : list sizeof Omean_vars;
		
	foreach var of local Omean_vars {;
				
		qui sum `var' if control == 1;
		 	local mean = r(mean);
		 	local sd = r(sd);
			
		replace Omean_medv = Omean_medv + ((`var'-`mean') / `sd');
		};
			
		replace Omean_medv = Omean_medv / `size';	
			
	/* -------------------------------------------------------- */
	/*	IV.D  Creating the Average of Control Variables			*/
	/* -------------------------------------------------------- */
		if "`dset'" == "0507" {; 
			local checkList : list controls_3 - newControls;
			foreach var of local checkList {; 
				egen `var' = rmean(`var'2005 `var'2007); 
		}; };


/* ======================================================== */
/*	V.  Mean Effects Regressions						    */
/* ======================================================== */
	local groupings = "comm group disp trust mean Omean";

	local label_comm  = "\hspace{5mm} Community Participation Mean Effect";
	local label_group = "\hspace{5mm} Group Membership Mean Effect";
	local label_disp  = "\hspace{5mm} Disputes Mean Effect";
	local label_trust = "\textbf{\textsc{Stated Trust Mean Effect}}";
	local label_mean  = "\textbf{\textsc{Collective Action Mean Effect}}";
	local label_Omean  = "TOTAL MEAN EFFECT";

foreach gp of local groupings {; 
	/* -------------------------------------------------------- */
	/*	V.A OLS Regressions										*/
	/* -------------------------------------------------------- */
	eststo clear;
	
	eststo: reg `gp'_medv `indvar' `MEcontrols_1' [pw = inv_prob_ch], robust; 

	eststo: reg `gp'_medv `indvar' `MEcontrols_3' [pw = inv_prob_ch], robust; 
		
	/* -------------------------------------------------------- */
	/*	V.C. IV Regressions										*/
	/* -------------------------------------------------------- */
 	eststo: ivreg2 `gp'_medv (`indvar' = `iv_ind') `MEcontrols_1'  [pw = inv_prob_ch], robust; 
        
 	eststo: ivreg2 `gp'_medv (`indvar' = `iv_ind') `MEcontrols_3'  [pw = inv_prob_ch], robust; 
    
		nlcom _b[`indvar']*`sigmaX';
			local `gp'_point = el(r(b),1,1);
			local `gp'_se = sqrt(el(r(V),1,1));
			local `gp'_ub 	 =  ``gp'_point' + (1.959964*``gp'_se');
			local `gp'_lb 	 =  ``gp'_point' - (1.959964*``gp'_se');
			
	label var `indvar' "`label_`gp''";	
	
	estout using "$outputRNR/mean_effects_`gp'_`indvar'_`meanEffectTitle'.tex", replace
		keep(`indvar') label 
		cells(b(fmt(3)) se(par star fmt(3)) .) dropped(".")
		starlevels(* 0.1 ** 0.05 *** 0.01) varwidth(15) 
		mlabels(, none) collabels(, none)
		substitute(_ \_) style(tex);				
	};


/* ======================================================== */
/*	VII.  Organizing Data for School Regressions			*/
/* ======================================================== */
	use "$DV_data/ethnic_school_05.dta", clear;	
	
	sort chief_2004census;
	
	merge m:1 chief_2004census using "$DV_data/newvars.dta";
		drop if _merge == 2;
		drop _merge;

	/* -------------------------------------------------------- */
	/* 	VII.A  Defining the control group		  	 		 	*/
	/* -------------------------------------------------------- */
	sum `indvar', detail;
		local cutoff = r(p50);
	gen control = (`indvar' < `cutoff');

	/* -------------------------------------------------------- */
	/* 	VII.B  Creating macros for groupings of variables    	*/
	/* -------------------------------------------------------- */
	local groupings = "supplies facil teach allSchool";
		local supplies_vars = "e_desks e_chairs e_pupilbench e_blackboard e_textbooks";
		local facil_vars  = "f_toilet f_elec f_piped_water f_bldg_good";
		local teach_vars  = "e_pupilteacher e_badteacher f_teacher_present_sur";
		
	local allSchool_vars : list supplies_vars | facil_vars;	
	local allSchool_vars : list allSchool_vars | teach_vars;	

	/* -------------------------------------------------------- */
	/* 	VII.C  Creating the z-score average dependent var   	*/
	/* -------------------------------------------------------- */
	foreach gp of local groupings {; 
		
		gen `gp'_medv = 0;
		
		foreach var of local `gp'_vars {;
				local size : list sizeof `gp'_vars;
				
				qui sum `var' if control == 1;
		 			local mean = r(mean);
		 			local sd = r(sd);
			
				replace `gp'_medv = `gp'_medv + ((`var'-`mean') / `sd');
			};
			
			replace `gp'_medv = `gp'_medv / `size';		
			sum `gp'_medv;
		};

/* ======================================================== */
/*	VIII.  Mean Effects Regressions:  Schooling				*/
/* ======================================================== */
	local label_allSchool = "Overall School Quality Mean Effect";
	local label_supplies = "\hspace{5mm} School Supplies Mean Effect";
	local label_facil 	 = "\hspace{5mm} School Building Quality Mean Effect";
	local label_teach 	 = "\hspace{5mm} Teaching Quality Mean Effect";

foreach gp of local groupings {; 	
	/* -------------------------------------------------------- */
	/* 	VIII.A  OLS Regressions									*/
	/* -------------------------------------------------------- */
	eststo clear;
	
	eststo : reg `gp'_medv `indvar' `MESchoolcontrols_1', robust; 

	eststo : reg `gp'_medv `indvar' `MESchoolcontrols_3', robust; 

		nlcom _b[`indvar']*`sigmaX';
			local `gp'_point = el(r(b),1,1);
			local `gp'_se = sqrt(el(r(V),1,1));
			local `gp'_ub 	 =  ``gp'_point' + (1.959964*``gp'_se');
			local `gp'_lb 	 =  ``gp'_point' - (1.959964*``gp'_se');
		
	/* -------------------------------------------------------- */
	/* 	VIII.C  LaTeX Output									*/
	/* -------------------------------------------------------- */
	label var `indvar' "`label_`gp''";	
	
	estout using "$outputRNR/mean_effects_`gp'_`indvar'_`meanEffectTitle'.tex", replace
		keep(`indvar') label 
		cells(b(fmt(3)) se(par star fmt(3)) .) dropped(".")
		starlevels(* 0.1 ** 0.05 *** 0.01) varwidth(15) 
		mlabels(, none) collabels(, none)
		substitute(_ \_) style(tex);				
	};
	
	foreach dv of local allSchool_vars {;
	
		gen `dv'_z = .;
		qui sum `dv' if control == 1;
		 	local mean = r(mean);
		 	local sd = r(sd);
		
		replace `dv'_z = ((`dv'-`mean') / `sd');	
				
		*regress `dv'_z `indvar' `MESchoolcontrols_3', robust;
		ivreg2 `dv'_z (`indvar' = `iv_ind') `MESchoolcontrols_3', robust;
		
		nlcom _b[`indvar']*`sigmaX';
			local `dv'_point = el(r(b),1,1);
			local `dv'_se = sqrt(el(r(V),1,1));
			local `dv'_ub 	 =  ``dv'_point' + (1.959964*``dv'_se');
			local `dv'_lb 	 =  ``dv'_point' - (1.959964*``dv'_se');
		};	


/* ======================================================== */
/*	VI. Plots of Estimates and Confidence Intervals			*/
/* ======================================================== */
	use "$DV_data/ethnic_ch_`dset'.dta", clear;

	merge m:1 chief_2004census using "$DV_data/schools_small.dta";
		drop if _merge == 2;
		drop _merge;
		
	foreach var of local schoolVarlist {;
		replace `var' = 0 if `var' == . & year == 2005;
		};

	keep group_any group_credit group_school road_brushing comm_labor comm_meetings 
		trust_own trust_outside trust_lc trust_cg dispute_theft dispute_land dispute_attack
		`schoolVarlist';
	drop if _n > 100;
	
	gen comm = 0;
	gen group = 0; 
	gen disp = 0;
	gen trust = 0;
	gen mean = 0;
	gen Omean = 0;
	gen allSchool = 0;
	gen facil = 0;
	gen supplies = 0;
	gen teach = 0;

	xpose, clear varname;
	
	drop v*;
	rename _varname varname;
		
	gen point = 0;
	gen se = 0;
	gen lb = 0;
	gen ub = 0;
	gen vname = 0;

		replace vname = 8 if varname == "mean";
		
		replace vname = 7 if varname == "comm";

		replace vname = 6 if varname == "group";

		replace vname = 5 if varname == "disp";

		replace vname = 4  if varname == "supplies";  
		
		replace vname = 3   if varname == "teach";
		
		replace vname = 2  if varname == "facil";		

		replace vname = 1 if varname == "trust";

	local plotlist = "point se lb ub";
	local varlist = "group_any group_credit group_school road_brushing comm_labor comm_meetings trust_own trust_outside
		trust_lc trust_cg dispute_theft dispute_land dispute_attack comm group disp trust mean Omean";
	
	local varlist2 = "allSchool supplies e_desks e_chairs e_pupilbench e_blackboard e_textbooks
		facil f_toilet f_elec f_piped_water f_bldg_good
		teach e_pupilteacher e_badteacher f_teacher_present_sur";
		
	local varlist : list varlist | varlist2;	
			
	foreach var of local varlist {;
		disp "varname == `var'";
		foreach p of local plotlist {;
		replace `p' = ``var'_`p'' if varname == "`var'";
		}; };
	
	label define vlabel 
		8 "Mean Effect:  Collective Action"
		7 "Mean Effect:  Community Participation"
		6 "Mean Effect:  Group Membership"
		5 "Mean Effect:  Disputes"
		4 "Mean Effect:  School Supplies"
		3 "Mean Effect:  Teaching Quality"
		2 "Mean Effect:  School Building Quality"
		1 "Mean Effect:  Stated Trust";
		
	sort vname;
	keep if vname > 0;

	label values vname vlabel;

	local end = 8;
			
	twoway (rcap lb ub vname, lcolor(black) msize(large) horizontal ylabel(1(1)`end', valuelabel angle(0)) 
		ytitle("") xtitle("Standard Deviation") xline(0) xscale(range(-0.5 0.5)) xlabel(-0.5(0.1)0.5)) 
		(rcap point point vname, lcolor(black) horizontal msize(large)), legend(off) graphregion(color(white));
	graph export "`figureString'", as(png) replace;	
	graph export "`figureStringPNG'", as(png) replace;	
	graph export "`figureStringEPS'", as(eps) replace;	
